#!/bin/bash

echo
echo -e "\e[37;44mПрограмма установки LDAP-сервера\e[00m"
echo
echo -e "\e[00;31mСейчас Вам нужно будет ответить на несколько вопросов\e[00m"
echo -e "1. \e[00;34m\033[1mВведите имя домена"
echo -e "например: lyceum130.ru"
echo -ne "\e[37;44mDOMAIN:\e[00m "
read DOMAIN
if [ "$DOMAIN" == "" ]
then
 echo -e "\e[00;31mERROR: Неверный формат. Пустая строка\e[00m"
 exit 0
fi

DOMAIN_TOK=`echo "$DOMAIN" | tr '.' ' '`
n=0
for i in $DOMAIN_TOK
do
    if [ $n == 0 ]; then
      LDAP_DOMAIN="dc="$i
      DOMAIN_FIRST_TOK=$i
      n=2
    else
      LDAP_DOMAIN=$LDAP_DOMAIN",dc="$i
    fi
done
echo -e "Имя LDAP-домена: $LDAP_DOMAIN"

echo
echo -e "2. \e[00;34m\033[1mВведите имя администратора домена"
echo -e "или нажмите Enter для admin"
echo -ne "\e[37;44mADMIN:\e[00m "
read ADMIN
if [ "$ADMIN" == "" ];then
ADMIN="admin"
fi
LDAP_ADMIN="cn="$ADMIN","$LDAP_DOMAIN
echo $LDAP_ADMIN
echo
echo -e "3. \e[00;34m\033[1mВведите пароль администратора домена"
echo -ne "\e[37;44mPASSWORD:\e[00m "
read PASSWORD
echo
if [ "$PASSWORD" == "" ]
then
 echo -e "\e[00;31m\033[1mERROR: Параль должен содержать хотябы 1 символ ))\e[00m"
 exit 0
fi

echo
echo -e "4. \e[00;34m\033[1mУстановка необходимого програмного обеспечения"
echo -e "Для установки требуется наличие подлюченя к сети интернет"
echo -en "Для продолжения нажмите Enter:\e[00m "
read ENTER
apt-get update
apt-get -y --force-yes install ldap-server ldap-utils

SSHA_PASSWORD=`slappasswd -s "$PASSWORD"`
#echo "$SSHA_PASSWORD"
echo
echo -e "\e[37;31m\033[1mТеперь в вашей системе установлено необходимое програмное обеспечение\e[00m"
echo

echo -e "5. \e[00;34m\033[1mПервичная настройка програмного обеспечения"
echo -en "Для продолжения нажмите Enter:\e[00m "
read ENTER
LDIF_FILE_PREFIX=`date +%s`
echo -e "dn: cn=module{0},cn=config\nobjectClass: olcModuleList\ncn: module\nolcModulepath: /usr/lib/ldap\nolcModuleload: {0}back_hdb\n\ndn: olcDatabase={1}hdb,cn=config\nobjectClass: olcDatabaseConfig\nobjectClass: olcHdbConfig\nolcDatabase: {1}hdb\nolcDbDirectory: /var/lib/ldap\nolcSuffix: $LDAP_DOMAIN\nolcRootDN: $LDAP_ADMIN\nolcRootPW: $PASSWORD\nolcDbConfig: {0}set_cachesize 0 2097152 0\nolcDbConfig: {1}set_lk_max_objects 1500\nolcDbConfig: {2}set_lk_max_locks 1500\nolcDbConfig: {3}set_lk_max_lockers 1500\nolcLastMod: TRUE\nolcDbCheckpoint: 512 30\nolcDbIndex: uid pres,eq\nolcDbIndex: cn,sn,mail pres,eq,approx,sub\nolcDbIndex: objectClass eq" > init_$LDIF_FILE_PREFIX.ldif
echo -e "\ndn: $LDAP_DOMAIN\nobjectClass: dcObject\nobjectclass: organization\no: $DOMAIN\ndc: $DOMAIN_FIRST_TOK\ndescription: My LDAP Root\n\ndn: $LDAP_ADMIN\nobjectClass: simpleSecurityObject\nobjectClass: organizationalRole\ncn: $ADMIN\nuserPassword: $SSHA_PASSWORD\ndescription: LDAP administrator" >> init_$LDIF_FILE_PREFIX.ldif
echo -e "\ndn: cn=config\nchangetype: modify\ndelete: olcAuthzRegexp\n\ndn: olcDatabase={-1}frontend,cn=config\nchangetype: modify\ndelete: olcAccess\n\ndn: olcDatabase={0}config,cn=config\nchangetype: modify\ndelete: olcRootDN\n\ndn: olcDatabase={0}config,cn=config\nchangetype: modify\nadd: olcRootDN\nolcRootDN: cn=$ADMIN,cn=config\n\ndn: olcDatabase={0}config,cn=config\nchangetype: modify\nadd: olcRootPW\nolcRootPW: $SSHA_PASSWORD\n\ndn: olcDatabase={0}config,cn=config\nchangetype: modify\ndelete: olcAccess" >> init_$LDIF_FILE_PREFIX.ldif
echo -e "dn: olcDatabase={1}hdb,cn=config\nadd: olcAccess\nolcAccess: to attrs=userPassword,shadowLastChange by dn=\"$LDAP_ADMIN\" write by anonymous auth by self write by * none\nolcAccess: to dn.base=\"\" by * read\nolcAccess: to * by dn=\"$LDAP_ADMIN\" write by * read\n" > init_r_$LDIF_FILE_PREFIX.ldif
ldapadd -Y EXTERNAL -H ldapi:/// -f /etc/ldap/schema/cosine.ldif
ldapadd -Y EXTERNAL -H ldapi:/// -f /etc/ldap/schema/inetorgperson.ldif
ldapadd -Y EXTERNAL -H ldapi:/// -f /etc/ldap/schema/nis.ldif
ldapadd -Y EXTERNAL -H ldapi:/// -f init_$LDIF_FILE_PREFIX.ldif
ldapmodify -x -w $PASSWORD -D $LDAP_ADMIN -f init_r_$LDIF_FILE_PREFIX.ldif

echo
echo -e "Теперь сервер LDAP настроен и доступен для подключения"
for i in `ifconfig | grep 'inet ' | tr ':' ' ' | awk '{print $3}'`; do
  IP=$IP$i" "
done
echo -e "\e[37;44m\033[1mпо адресам:                \e[00;31m\033[1m$IP"
echo -e "\e[37;44mLDAP-домен:                \e[00;31m\033[1m$LDAP_DOMAIN"
echo -e "\e[37;44mадминистратор LDAP-домена: \e[00;31m\033[1m$LDAP_ADMIN"
echo -e "\e[37;44mпароль администратора:     \e[00;31m\033[1m$PASSWORD\e[00m"
read ENTER
rm init_$LDIF_FILE_PREFIX.ldif init_r_$LDIF_FILE_PREFIX.ldif
